package MHonArc::UTF8::ISO8859_3;
+{
'',' ',
'','Ħ',
'','˘',
'','£',
'','¤',
'','Ĥ',
'','§',
'','¨',
'','İ',
'','Ş',
'','Ğ',
'','Ĵ',
'','­',
'','Ż',
'','°',
'','ħ',
'','²',
'','³',
'','´',
'','µ',
'','ĥ',
'','·',
'','¸',
'','ı',
'','ş',
'','ğ',
'','ĵ',
'','½',
'','ż',
'','À',
'','Á',
'','Â',
'','Ä',
'','Ċ',
'','Ĉ',
'','Ç',
'','È',
'','É',
'','Ê',
'','Ë',
'','Ì',
'','Í',
'','Î',
'','Ï',
'','Ñ',
'','Ò',
'','Ó',
'','Ô',
'','Ġ',
'','Ö',
'','×',
'','Ĝ',
'','Ù',
'','Ú',
'','Û',
'','Ü',
'','Ŭ',
'','Ŝ',
'','ß',
'','à',
'','á',
'','â',
'','ä',
'','ċ',
'','ĉ',
'','ç',
'','è',
'','é',
'','ê',
'','ë',
'','ì',
'','í',
'','î',
'','ï',
'','ñ',
'','ò',
'','ó',
'','ô',
'','ġ',
'','ö',
'','÷',
'','ĝ',
'','ù',
'','ú',
'','û',
'','ü',
'','ŭ',
'','ŝ',
'','˙',
};
